Module values

Module values 

Structs

HeaderName
Represents an HTTP header field name
HeaderValue
Represents an HTTP header field value.
HeaderValues
Contains all http header values.
InvalidHeaderValue
A possible error when converting a HeaderValue from a string or byte slice.
JsonError
This type represents all possible errors that can occur when serializing or deserializing JSON data.

Traits

AsHeaderName
A marker trait used to identify values that can be used as search keys to a HeaderMap.
IntoEncodedHeaderValue
Converts a value into a HeaderValue and encodes it if necessary.
IntoHeaderName
A marker trait used to identify values that can be used as insert keys to a HeaderMap.