pub struct Request { /* private fields */ }Expand description
The Request that get’s returned to every route.
Implementations
sourceimpl Request
impl Request
sourcepub fn take_body(&mut self) -> BodyWithTimeout
pub fn take_body(&mut self) -> BodyWithTimeout
Takes the current body and leaves the request with an empty body.
sourcepub fn take_raw_body(&mut self) -> Body
pub fn take_raw_body(&mut self) -> Body
Takes the current body and leaves the request an empty body.
This discard the timout associated with the body.
sourcepub fn body(&self) -> &BodyWithTimeout
pub fn body(&self) -> &BodyWithTimeout
Returns a reference to the body contained in the request.
sourcepub fn body_mut(&mut self) -> &mut BodyWithTimeout
pub fn body_mut(&mut self) -> &mut BodyWithTimeout
Returns a mutable reference to the body contained in the request.
sourcepub fn raw_body(&self) -> &Body
pub fn raw_body(&self) -> &Body
Returns a reference to the body contained in the request without a timeout being associated with it.
sourcepub fn raw_body_mut(&mut self) -> &mut Body
pub fn raw_body_mut(&mut self) -> &mut Body
Returns a reference to the body contained in the request without a timeout being associated with it.
sourcepub fn set_size_limit(&mut self, size_limit: usize)
pub fn set_size_limit(&mut self, size_limit: usize)
Changes the size limit of the current request.
sourcepub fn set_timeout(&mut self, duration: Duration)
pub fn set_timeout(&mut self, duration: Duration)
Changes the timeout of the current request.
sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Returns a reference to the request header.
sourcepub fn header_mut(&mut self) -> &mut RequestHeader
pub fn header_mut(&mut self) -> &mut RequestHeader
Returns a mutable reference to the request header.