Struct fire_http::body::BodyWithTimeout
source · [−]pub struct BodyWithTimeout { /* private fields */ }Expand description
Adds a timeout to any Body.
Implementations
sourceimpl BodyWithTimeout
impl BodyWithTimeout
sourcepub fn from_hyper_body(
body: Body,
max_size: usize,
timeout: Duration
) -> BodyWithTimeout
pub fn from_hyper_body(
body: Body,
max_size: usize,
timeout: Duration
) -> BodyWithTimeout
Creates a BodyWithTimeout from a hyper::Body.
Panics while reading
If the body was already read more than the max_size or the max_size is 0.
sourcepub fn take(&mut self) -> BodyWithTimeout
pub fn take(&mut self) -> BodyWithTimeout
Creates a new BodyWithTimeout leaving the old one, with an empty Body.
sourcepub fn set_size_limit(&mut self, max_size: usize) -> bool
pub fn set_size_limit(&mut self, max_size: usize) -> bool
Sets a read size limit to the HyperBody. Returns true if the size limit was set.
Note
Works only with the hyper_body feature.
When the size limit is reached an io::Error::Other with SizeLimitReached
is returned.
Panics while reading
If the body was already read more than the max_size or the max_size is 0.
sourcepub fn set_timeout(&mut self, timeout: Duration)
pub fn set_timeout(&mut self, timeout: Duration)
Sets the timeout.
sourcepub async fn into_more_bytes(self) -> Result<MoreBytes, Error>
pub async fn into_more_bytes(self) -> Result<MoreBytes, Error>
Converts the body into MoreBytes returning an error if reading failed or the size limit was reached.
sourcepub async fn into_string(self) -> Result<String, Error>
pub async fn into_string(self) -> Result<String, Error>
Converts the body into a String.
Note
If possible, avoid this function as it is really inefficient.
For tests or quick debugging however it is quite suitable.