Module fire_http::header::values

source ·

Structs

Represents an HTTP header field name
Represents an HTTP header field value.
Contains all http header values.
A possible error when converting a HeaderValue from a string or byte slice.
This type represents all possible errors that can occur when serializing or deserializing JSON data.

Traits

A marker trait used to identify values that can be used as search keys to a HeaderMap.
Converts a value into a HeaderValue and encodes it if necessary.
A marker trait used to identify values that can be used as insert keys to a HeaderMap.